@@ -6,7 +6,7 @@ import updater4pyi.util
 import os.path
 
 def locpath(x):
-    return os.path.realpath(os.path.join(os.path.dirname(updater4pyi.__file__), '..', x))
+    return os.path.realpath(os.path.join(os.path.dirname(updater4pyi.__file__), x))
 
 datas = [
     (locpath('cacert.pem'), 'updater4pyi'),
@@ -23,4 +23,4 @@ elif updater4pyi.util.is_win():
 
 #from hookutils import collect_data_files
 #datas = collect_data_files('updater4pyi')
-#print "DATAS IS\n\t%r"%(datas)
+print "DATAS IS\n\t%r"%(datas)
